OC.L10N.register(
    "notes",
    {
    "Notes" : "Notizen",
    "Error" : "Fehler",
    "Help" : "Hëllef",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "Rename" : "Ëmbenennen",
    "Details" : "Detailer",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Edit" : "Änneren",
    "Tasks" : "Tâchen"
},
"nplurals=2; plural=(n != 1);");
